@@ -55,6 +55,7 @@ from cl_distr import (PartitionDistributive,
 from calculate.lib.utils.text import tableReport
 from calculate.lib.server.utils import dialogYesNo
 from subprocess import Popen,PIPE,STDOUT
+from itertools import *
 
 class InstallError(Exception):
     """Installation Error"""
@@ -185,67 +186,26 @@ class Install(color_print):
 
 #        cltObj = True if 'clt' in templates_locate else False
         dirs_list, files_list = ([],[])
-        listTemplatePaths = ["/var/lib/layman/calculate/profiles/templates",
-                            "/var/calculate/templates",
-                            "/var/calculate/remote/templates"]
-        for location in templates_locate:
-            if location in ("overlay", "local", "remote", "clt"):
-                if len(listTemplatePaths) != 3:
-                    self.printERROR(\
-                    _("Error in template variable 'cl_template_path=%s'")\
-                    %str(listTemplatePaths))
-                    return False
-                elif location == "local":
-                    if not os.path.isdir(listTemplatePaths[1]):
-                        continue
-                    self.clVars.Set("cl_template_path",
-                                    [listTemplatePaths[1]], True)
-                elif location == "remote":
-                    if not os.path.isdir(listTemplatePaths[2]):
-                        continue
-                    self.clVars.Set("cl_template_path",
-                               [listTemplatePaths[2]], True)
-                elif location == "overlay":
-                    if not os.path.isdir(listTemplatePaths[0]):
-                        continue
-                    self.clVars.Set("cl_template_path",
-                               [listTemplatePaths[0]], True)
-                elif location == "clt":
-#                    list_paths = ['/etc'] + \
-#                                    os.environ.get('CONFIG_PROTECT').split()
-#                    for template_path in list_paths:
-#                        if not os.path.isdir(template_path):
-#                            continue
-#                        print template_path
-#                        self.clVars.Set("cl_template_path",
-#                                        [template_path], True)
-#                        self.clTempl = ProgressTemplate(self.setProgress,
-#                                                    self.clVars,cltObj=True,
-#                                                    cltFilter=True)
-#
-#                        dirsFiles = self.clTempl.applyTemplates()
-#        #                cltObj = False
-#                        print dirsFiles
-#                        dirs_list += (dirsFiles[0])
-#                        files_list += (dirsFiles[1])
-                    continue
+        useClt = "clt" in templates_locate
+        self.clVars.Set("cl_template_path",
+            map(lambda x:x[1],
+            filter(lambda x:x[0] in templates_locate,
+            zip(self.clVars.Get('cl_template_location'),
+                self.clVars.Get('cl_template_path')))),
+            True)
 
-                self.clTempl = ProgressTemplate(self.setProgress, self.clVars,
-                                                cltFilter=False)
+        self.clTempl = ProgressTemplate(self.setProgress, self.clVars,
+                                        cltObj=useClt,
+                                        cltFilter=False)
 
-                dirsFiles = self.clTempl.applyTemplates()
-                if type(dirsFiles) in [list, tuple]:
-                    if len (dirsFiles) > 1:
-                        dirs_list += (dirsFiles[0])
-                        files_list += (dirsFiles[1])
-        self.clVars.Set("cl_template_path", listTemplatePaths, True)
+        dirsFiles = self.clTempl.applyTemplates()
         try:
             if self.clTempl.getError():
                 self.printERROR(self.clTempl.getError())
                 return False
         except AttributeError:
             pass
-        return (dirs_list, files_list)
+        return dirsFiles
 
     def applyTemplatesFlash(self,directory):
         """Apply templates for root of system."""
@@ -386,17 +346,34 @@ class Install(color_print):
             raise DistributiveError(
                 _("Failed to determine the partition number for %s")%partition)
         bootFlag = "boot" if parttable == "dos" else "legacy_boot"
-        parted = process(partedProg, "-m",deviceName,"print")
-        DEVICENUM,FLAGS = 0,6
-        changeActive = \
-            map(lambda x:x[DEVICENUM],
-            filter(lambda x:x[DEVICENUM] != partitionNumber and \
-                            bootFlag in x[FLAGS].strip(';').split(', ') or \
-                            x[DEVICENUM] == partitionNumber and \
-                            not bootFlag in x[FLAGS].strip(';').split(', '),
-            filter(lambda x:len(x)>=7,
-            map(lambda x:x.split(':'),
-            parted.readlines()[2:]))))
+        if parttable == "dos":
+            fdisk = process(fdiskProg, "-l",deviceName)
+            DEVICENUM,AFLAG = 0,1
+            changeActive = \
+                map(lambda x:x[DEVICENUM],
+                filter(lambda x:x[DEVICENUM] != partitionNumber and \
+                                x[AFLAG] == "*" or \
+                                x[DEVICENUM] == partitionNumber and \
+                                not x[AFLAG] == "*",
+                list(map(lambda x:[str(x[0]),x[1][1].strip()],
+                # enumerate partitions
+                enumerate(filter(None,
+                map(lambda x:x.split()[:2],
+                # drop string before information about partitions
+                dropwhile(lambda x:not x.lstrip().startswith("Device"),
+                fdisk.readlines()))))))[1:]))
+        else:
+            parted = process(partedProg, "-m",deviceName,"print")
+            DEVICENUM,FLAGS = 0,6
+            changeActive = \
+                map(lambda x:x[DEVICENUM],
+                filter(lambda x:x[DEVICENUM] != partitionNumber and \
+                                bootFlag in x[FLAGS].strip(';').split(', ') or \
+                                x[DEVICENUM] == partitionNumber and \
+                                not bootFlag in x[FLAGS].strip(';').split(', '),
+                filter(lambda x:len(x)>=7,
+                map(lambda x:x.split(':'),
+                parted.readlines()[2:]))))
         if not changeActive:
             return True
         if parttable == "dos":
@@ -480,7 +457,7 @@ class Install(color_print):
                 self.clVars.Get('cl_action') != "system":
                 prefixBoot = "/mnt/scratch"
             else:
-                prefixBoot = ""
+                prefixBoot = "/"
             grubProcess = process(cmdGrubInstall,
                               "--boot-directory=%s"%pathJoin(prefixBoot,
                               target.getBootDirectory()),
