@@ -23,7 +23,7 @@ from soaplib.service import rpc, DefinitionBase
 from calculate.core.server.api_types import ReturnedMessage
 from calculate.core.server.api_types import ChoiceValue, Table, Option, Field, \
                                            GroupField, ViewInfo, ViewParams
-from calculate.lib.datavars import VariableError
+from calculate.lib.datavars import VariableError,DataVarsError
 
 #from cl_install import Install,DataVarsInstall
 import cl_install
@@ -107,8 +107,10 @@ class catchExcept:
                     default = 'color:red;',
                     element = "error"))
             view.groups.append(group)
-            #for i in apply(traceback.format_exception, sys.exc_info()):
-            #    print i
+            if not isinstance(VariableError,DataVarsError,InstallError):
+                for i in apply(traceback.format_exception, sys.exc_info()):
+                    print i,
+
             return view
 
 class Wsdl:
@@ -232,13 +234,13 @@ class Wsdl:
             lang = dv.Get('os_install_locale_lang')
             self.set_cache(sid,"install","lang",lang,smart=False)
             dv.processRefresh()
+        self.set_cache(sid, 'install', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief,
                            has_brief=True,
                            allsteps=langChanged,
                            brief_label=_("Start installing"))
-        self.set_cache(sid, 'install', "vars",dv,smart=False)
         return view
 
     def install_flash_vars(self):
@@ -272,10 +274,10 @@ class Wsdl:
             dv = self.install_flash_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'install_flash', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'install_flash', "vars",dv,smart=False)
         return view
 
     def install_pxe_vars(self):
@@ -309,10 +311,10 @@ class Wsdl:
             dv = self.install_pxe_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'install_pxe', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'install_pxe', "vars",dv,smart=False)
         return view
 
     def setup_network_vars(self):
@@ -351,10 +353,10 @@ class Wsdl:
             dv = self.setup_network_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'setup_network', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'setup_network', "vars",dv,smart=False)
         return view
 
     def setup_video_vars(self):
@@ -391,10 +393,10 @@ class Wsdl:
             dv = self.setup_video_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'setup_video', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'setup_video', "vars",dv,smart=False)
         return view
 
     def setup_locale_vars(self):
@@ -431,10 +433,10 @@ class Wsdl:
             dv = self.setup_locale_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'setup_locale', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'setup_locale', "vars",dv,smart=False)
         return view
 
     def setup_boot_vars(self):
@@ -470,10 +472,10 @@ class Wsdl:
             dv = self.setup_boot_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'setup_boot', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'setup_boot', "vars",dv,smart=False)
         return view
 
     def setup_system_vars(self):
@@ -507,8 +509,8 @@ class Wsdl:
             dv = self.setup_system_vars()
         else:
             dv.processRefresh()
+        self.set_cache(sid, 'setup_system', "vars",dv,smart=False)
         view = ViewInfo(dv,step=params.step,
                            expert=params.expert,
                            brief=params.brief)
-        self.set_cache(sid, 'setup_system', "vars",dv,smart=False)
         return view
