@@ -28,7 +28,7 @@ from calculate.lib.datavars import (TableVariable,Variable,VariableError,
 from calculate.lib.utils.device import (getUdevDeviceInfo,getDeviceType,
                         getPartitionType,getPartitionDevice,getRaidPartitions,
                         getLvmPartitions,getPartitionSize, humanreadableSize,
-                        getUUIDDict)
+                        getUUIDDict,getCommonDeviceName)
 from calculate.lib.utils.files import (listDirectory,pathJoin,readFile,FStab,
                                        isMount)
 from calculate.install.cl_distr import PartitionDistributive
@@ -619,6 +619,9 @@ class VariableOsLocationData(LocationHelper,TableVariable):
                       "to specify the source directory as DISK")
         self.label = _("Locations")
 
+    def set(self,value):
+        return sorted(value,key=lambda x:x[0])
+
 class VariableOsLocationSource(LocationHelper,DeviceHelper,Variable):
     """
     Source disk or directory
@@ -705,7 +708,10 @@ class VariableOsLocationSource(LocationHelper,DeviceHelper,Variable):
         # check wrong dev
         ###########################
         disks = filter(lambda x:x.startswith('/dev/'),value)
-        wrongDevices = list(set(disks) - \
+        # get original /dev names
+        cnDisks = map(lambda x:getUdevDeviceInfo(name=x).get('DEVNAME',x),
+                  disks)
+        wrongDevices = list(set(cnDisks) - \
                     set(self.fixOsDiskDev()))
         if wrongDevices:
             raise VariableError(_("Wrong device '%s'")%wrongDevices[0])
@@ -763,10 +769,7 @@ class VariableOsLocationDest(LocationHelper,Variable):
                 return path.normpath(val)
             return val
         value = map(normpath,value)
-        if len(value) == 1 and value[0] == "":
-            return ["/"]
-        else:
-            return value
+        return map(lambda x:x or "/",value)
 
     def choice(self):
         if self.Get('cl_install_type') == 'flash': return ["/",""]
@@ -1096,6 +1099,12 @@ class VariableOsLocationSize(LocationHelper,SourceReadonlyVariable):
                 self.Get('cl_autopartition_disk_size')))
         return mapDevSize
 
+    def get(self):
+        return map(lambda x:x or "",
+               map(self.getMap().get,
+               map(getCommonDeviceName,
+               self.Get(self.indexField))))
+
     def getMapHumanReadable(self):
         #return map(lambda x:humanreadableSize(x) if x else "",
         #       self.Get())
@@ -1106,6 +1115,13 @@ class VariableOsLocationSize(LocationHelper,SourceReadonlyVariable):
                 self.Get('cl_autopartition_disk_size',humanreadable=True)))
         return mapDevSize
 
+    def humanReadable(self):
+        return map(lambda x:x or "",
+               map(self.getMapHumanReadable().get,
+               map(getCommonDeviceName,
+               self.Get(self.indexField))))
+
+
 class VariableClUuidSet(Variable):
     """
     Use or not UUID for /etc/fstab
@@ -1147,10 +1163,11 @@ class VariableOsInstallDiskDev(ReadonlyVariable):
     type = "list"
 
     def get(self):
-        return map(lambda x:x[0],
+        return map(getCommonDeviceName,
+               map(lambda x:x[0],
                filter(lambda x:x[0].startswith('/dev/') and x[1],
                zip(self.Get('os_location_source'),
-                   self.Get('os_location_dest'))))
+                   self.Get('os_location_dest')))))
 
 class VariableOsInstallDiskUuid(ReadonlyVariable):
     """
@@ -1541,9 +1558,12 @@ class VariableOsInstallRootType(LocationHelper,Variable):
 class VariableOsInstallRootDev(ReadonlyVariable):
     def get(self):
         """Get install root device"""
-        return self.Select('os_install_disk_dev',
-                           where='os_install_disk_mount',
-                           eq="/",limit=1) or ''
+        if self.Get('cl_action') == 'system':
+            return self.Select('os_install_disk_dev',
+                               where='os_install_disk_mount',
+                               eq="/",limit=1) or ''
+        else:
+            return self.Get('os_root_dev')
 
 class VariableOsInstallFstabMountConf(ReadonlyVariable,DeviceHelper):
     """
