@@ -316,7 +316,7 @@ class VariableClImageFilename(Variable,DistroRepository):
             discardType = []
         distros = self.getAvailableDristibutives(imagePath,
                                         discardType=discardType)
-        if self.wasSet:
+        if self.wasSet and not self.value in distros:
             distros.append(self.value)
         return sorted(map(lambda x:(x,
                           self.humanImageName(self._getDistrInfo(x),x)),
